# gutmetrics
A Python package for predicting gut microbiome α-diversity from blood metabolomics data, based on the research published in Blood metabolome predicts gut microbiome α-diversity in humans.
